
struct PSInput
{
	float4 position : SV_POSITION;
};

Texture2D g_texture : register(t0);
SamplerState g_sampler : register(s0);
Texture2D g_blur : register(t1);
SamplerState g_blurSampler : register(s1);

cbuffer cb0 : register(b0)
{
	float4x4 mvMat;
	float4x4 projMat;
	float2 screenSize;
};

PSInput VSMain(float3 position : POSITION)
{
	PSInput result;

	float4x4 finalMatrix = mul(projMat, mvMat);
	result.position = mul(finalMatrix, float4(position, 1.0));

	return result;
}

float4 PSMain(PSInput input) : SV_TARGET
{
	float2 uv = input.position.xy / screenSize;

	uv.y = 1.0 - uv.y;
	float4 color = g_texture.Sample(g_sampler, uv);
	float4 blur = g_blur.Sample(g_blurSampler, uv);

	float3 composite = color.rgb + blur.rgb * blur.a;
	//Tonemapping:
	float exposure = 2.5;
	composite = float3(1.0, 1.0, 1.0) - exp(-composite * exposure);
	//End Tonemapping

	float gammaValue = 1.2;
	float3 gamma = float3(1.0/gammaValue, 1.0/gammaValue, 1.0/gammaValue);
	return float4(pow(composite, gamma), 1.0);
}
