
struct PSInput
{
	float4 position : SV_POSITION;
};

Texture2D g_texture : register(t0);
SamplerState g_sampler : register(s0);
Texture2D g_depth : register(t1);
SamplerState g_depthSampler : register(s1);

cbuffer cb0 : register(b0)
{
	float4x4 mvMat;
	float4x4 projMat;
	float2 screenSize;
};

PSInput VSMain(float3 position : POSITION)
{
	PSInput result;

	float4x4 finalMatrix = mul(projMat, mvMat);
	result.position = mul(finalMatrix, float4(position, 1.0));

	return result;
}

float4 PSMain(PSInput input) : SV_TARGET
{
	float2 uv = input.position.xy / screenSize;
	uv.y = 1.0 - uv.y;

	float depth = g_depth.Sample(g_depthSampler, uv).r;

	float3 color;
	float radius = 0.0;
	float blurStart = 0.89*2.0-1.0;
	float blurEnd = 0.998*2.0-1.0;
	float scale = 200.0;

	color = g_texture.Sample(g_sampler, uv).rgb;

#if 0
	radius = (depth - blurEnd) * scale;
#else
	if(depth < blurStart)
	{
		radius = 0.0;
	}
	else
	{
		radius = (min(depth, blurEnd)-blurStart) * scale;
	}
#endif

	return float4(color, radius);
}
