#version 150
#ifdef VERTEX_SHADER_SOURCE

uniform mat4 mvMat;
uniform mat4 projMat;

in vec3 inVertex;

void main(void)
{
	mat4 finalMatrix = projMat * mvMat;
	gl_Position = finalMatrix * vec4(inVertex, 1.0);
}
#endif

#ifdef FRAGMENT_SHADER_SOURCE
uniform vec2 screenSize;

uniform sampler2D texture0;//colors

out vec4 outColor;

void main(void)
{
	vec2 uv = gl_FragCoord.xy / screenSize;

	const int maxCoCRadiusInPixels = 5;
	const vec2 direction = vec2(1.0, 0.0);

	vec4 color = texture(texture0, uv);
	float radius = 0.0;
	float blurWeightSum = 0.0;

#ifdef FIX_BLEEDING
	float n_A = color.a * 2.0 - 1.0;
#endif

	if(color.a == 0.0)
	{
	}
	else
	{
		vec3 newColor = vec3(0.0);

		const int KERNEL_TAPS = 6;
		float kernel[KERNEL_TAPS + 1];
		// 11 x 11 separated kernel weights.  This does not dictate the
		// blur kernel for depth of field; it is scaled to the actual
		// kernel at each pixel.
		kernel[6] = 0.00000000000000;  // Weight applied to outside-radius values

		// Custom // Gaussian
		kernel[5] = 0.50;//0.04153263993208;
		kernel[4] = 0.60;//0.06352050813141;
		kernel[3] = 0.75;//0.08822292796029;
		kernel[2] = 0.90;//0.11143948794984;
		kernel[1] = 1.00;//0.12815541114232;
		kernel[0] = 1.00;//0.13425804976814;

		for(int delta = -maxCoCRadiusInPixels; delta <= maxCoCRadiusInPixels; ++delta)
		{
			vec2 B = uv + (direction * float(delta)) / screenSize;
			vec4 colorInput = texture(texture0, B);
			float n_B = colorInput.a * 2.0 - 1.0;
#ifdef FIX_BLEEDING
			if(n_B <= n_A)
#endif
			{
				float r_B = sign(n_B) * 3.0 + n_B * max(0.0, float(maxCoCRadiusInPixels) - 3.0);

				float weight = kernel[clamp(int(float(abs(delta) * (KERNEL_TAPS - 1)) / (0.001 + abs(r_B * 0.8))), 0, KERNEL_TAPS)];

				blurWeightSum += weight;
				newColor.rgb += colorInput.rgb * weight;
			}
		}
		color.rgb = newColor / blurWeightSum;
	}

	outColor = color;
}
#endif
