
struct PSInput
{
	float4 position : SV_POSITION;
};

Texture2D g_texture : register(t0);
SamplerState g_sampler : register(s0);

cbuffer cb0 : register(b0)
{
	float4x4 mvMat;
	float4x4 projMat;
	float2 screenSize;
};

PSInput VSMain(float3 position : POSITION)
{
	PSInput result;

	float4x4 finalMatrix = mul(projMat, mvMat);
	result.position = mul(finalMatrix, float4(position, 1.0));

	return result;
}

float4 PSMain(PSInput input) : SV_TARGET
{
	float2 uv = input.position.xy / screenSize;
	uv.y = 1.0 - uv.y;

	const int maxCoCRadiusInPixels = 5;
	const float2 direction = float2(1.0, 0.0);

	float4 color = g_texture.Sample(g_sampler, uv);
	float radius = 0.0f;
	float blurWeightSum = 0.0;

	if(color.a == 0.0)
	{
	}
	else
	{
		float3 newColor = float3(0.0, 0.0, 0.0);

		const int KERNEL_TAPS = 6;
		float kernel[KERNEL_TAPS + 1];
		// 11 x 11 separated kernel weights.  This does not dictate the
		// blur kernel for depth of field; it is scaled to the actual
		// kernel at each pixel.
		kernel[6] = 0.00000000000000;  // Weight applied to outside-radius values

		// Custom // Gaussian
		kernel[5] = 0.50;//0.04153263993208;
		kernel[4] = 0.60;//0.06352050813141;
		kernel[3] = 0.75;//0.08822292796029;
		kernel[2] = 0.90;//0.11143948794984;
		kernel[1] = 1.00;//0.12815541114232;
		kernel[0] = 1.00;//0.13425804976814;

		for(int delta = -maxCoCRadiusInPixels; delta <= maxCoCRadiusInPixels; ++delta)
		{
			float2 B = uv + (direction * float(delta)) / screenSize;
			float4 colorInput = g_texture.SampleLevel(g_sampler, B, 0);
			float n_B = colorInput.a * 2.0 - 1.0;


			float r_B = sign(n_B) * 3.0 + n_B * max(0.0, float(maxCoCRadiusInPixels) - 3.0);
			float weight = kernel[clamp(int(float(abs(delta) * (KERNEL_TAPS - 1)) / (0.001 + abs(r_B * 0.8))), 0, KERNEL_TAPS)];

			blurWeightSum += weight;
			newColor.rgb += colorInput.rgb * weight;

		}
		color.rgb = newColor / blurWeightSum;
	}

	return float4(color.rgb, 1.0f);
}
