#version 150
#ifdef VERTEX_SHADER_SOURCE

uniform mat4 mvMat;
uniform mat4 projMat;

in vec3 inVertex;

void main(void)
{
	mat4 finalMatrix = projMat * mvMat;
	gl_Position = finalMatrix * vec4(inVertex, 1.0);
}
#endif

#ifdef FRAGMENT_SHADER_SOURCE
uniform vec2 screenSize;

uniform sampler2D texture0;//colors

out vec4 outColor;

void main(void)
{
	vec2 uv = gl_FragCoord.xy / screenSize;

	const int blurRadiusInPixels = 5;
	const vec2 direction = vec2(1.0, 0.0);

	vec4 color;// = texture(texture0, uv);
	float blurWeightSum = 0.0;

	vec3 newColor = vec3(0.0);

	const int KERNEL_TAPS = 6;
	float kernel[KERNEL_TAPS + 1];
	// 11 x 11 separated kernel weights.  This does not dictate the
	// blur kernel for depth of field; it is scaled to the actual
	// kernel at each pixel.
	kernel[6] = 0.00000000000000;  // Weight applied to outside-radius values

	// Gaussian
	kernel[5] = 0.04153263993208;
	kernel[4] = 0.06352050813141;
	kernel[3] = 0.08822292796029;
	kernel[2] = 0.11143948794984;
	kernel[1] = 0.12815541114232;
	kernel[0] = 0.13425804976814;

	for(int delta = -blurRadiusInPixels; delta <= blurRadiusInPixels; ++delta)
	{
		vec2 B = uv + (direction * float(delta)) / screenSize;
		vec4 colorInput = texture(texture0, B);

		float weight = kernel[clamp(abs(delta), 0, KERNEL_TAPS)];

		blurWeightSum += weight;
		newColor.rgb += colorInput.rgb * weight;

	}
	color.rgb = newColor / blurWeightSum;//float(blurRadiusInPixels*2+1);

	outColor = vec4(color.rgb, 1);
}
#endif
