#version 130
#ifdef VERTEX_SHADER_SOURCE

uniform mat4 mvMat;
uniform mat4 projMat;
uniform mat4 modelMat;
uniform mat3 inverseModelMat;

in vec3 inVertex;
in vec2 inTexCoord;
in vec3 inColor;
in vec3 inNormal;
out vec4 color;
out vec2 texCoord;
out vec4 pointInWorld;
out vec3 normal;
out vec4 worldVertex;

void main(void)
{
	mat4 finalMatrix = projMat * mvMat;
	gl_Position = finalMatrix * vec4(inVertex, 1.0);
	pointInWorld = mvMat * vec4(inVertex, 1.0);
	color = vec4(inColor, 1.0);
	texCoord = inTexCoord;

	mat3 normalMatrix = transpose(inverseModelMat);
	normal = normalize(normalMatrix * inNormal);

	worldVertex = modelMat * vec4(inVertex, 1.0);
}
#endif

#ifdef FRAGMENT_SHADER_SOURCE
uniform vec3 lightDirection;
uniform sampler2D texture0;
uniform int highlight;
uniform vec3 spotPosition;
uniform vec3 lightMultiplier;

in vec4 color;
in vec2 texCoord;
in vec4 pointInWorld;
in vec3 normal;
in vec4 worldVertex;
out vec4 outColor;

void main(void) {
	vec4 textureColor = color*texture(texture0, texCoord.st);
	if(textureColor.a < 0.3)
		discard;

	vec4 fragColor = textureColor;

	vec3 ambient = 0.1 * fragColor.rgb;
	float diffuseCoefficient = max(0.0, dot(normal, -lightDirection.xyz));
	vec3 diffuse = diffuseCoefficient * fragColor.rgb;

	/*float specularCoefficient = 0.0;
    if(diffuseCoefficient > 0.0)
        specularCoefficient = pow(max(0.0, dot(surfaceToCamera, reflect(-surfaceToLight, normal))), materialShininess);*/

	fragColor.rgb = ambient+diffuse;//mix(ambient+diffuse, ambient, clamp(-worldVertex.z/20.0, 0.0, 1.0));

	fragColor *= vec4(lightMultiplier,1);

	//POINT LIGHT
	{
		vec3 spotDirection = vec3(0.0, 0.0, -1.0);
		vec3 surfaceToLight = normalize(spotPosition - worldVertex.xyz);
		float distanceToLight = length(spotPosition - worldVertex.xyz);
		float diffuseCoefficient = max(0.0, dot(normal, surfaceToLight));
		float lightAttenuation = 0.01;
		vec3 lightIntensity = vec3(0.3, 0.3, 0.3);
		float attenuation = 1.0 / (1.0 + lightAttenuation * pow(distanceToLight, 2));

		float spotExteriorAngle = 60.0;
		float spotInteriorAngle = 40.0;
		float lightToSurfaceAngle = acos(dot(-surfaceToLight, normalize(spotDirection))) / 0.017453292519943;
		if(lightToSurfaceAngle > spotInteriorAngle)
		{
			float attenuationFactor = clamp(mix(0.0, 1.0, (lightToSurfaceAngle-spotInteriorAngle)/(spotExteriorAngle-spotInteriorAngle)), 0.0, 1.0);
			attenuationFactor = 1.0 - attenuationFactor;
			attenuation *= attenuationFactor;
		}

		fragColor.rgb += lightIntensity*diffuseCoefficient*attenuation * textureColor.rgb;
	}
	//END POINT LIGHT

	float blendFactor = clamp(length(pointInWorld)/80.0, 0.0, 1.0);

	//vec3 gamma = vec3(1/2.2);

	float alpha = 1.0;
	if(highlight == 1)
	{
		//alpha = 2.0;
		//Tmp before we get a real highlight shader:
		fragColor.rgb = textureColor.rgb;
	}
    outColor = vec4(fragColor.rgb, alpha);//vec4(pow(outColor.rgb, gamma), 1.0);
}
#endif
