//*********************************************************
//
// Copyright (c) Microsoft. All rights reserved.
// This code is licensed under the MIT License (MIT).
// THIS CODE IS PROVIDED *AS IS* WITHOUT WARRANTY OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING ANY
// IMPLIED WARRANTIES OF FITNESS FOR A PARTICULAR
// PURPOSE, MERCHANTABILITY, OR NON-INFRINGEMENT.
//
//*********************************************************

struct PSInput
{
	float4 position : SV_POSITION;
	float2 uv : TEXCOORD;
	float4 color : COLOR;
	float4 normal : NORMAL;
};

Texture2D g_texture : register(t0);
SamplerState g_sampler : register(s0);

cbuffer cb0 : register(b0)
{
	float4x4 mvMat;
	float4x4 projMat;
	
	float4x4 joints[32];
};

PSInput VSMain(float3 position : POSITION, float2 uv : TEXCOORD, float3 color : COLOR, float3 normal: NORMAL, int4 jointIndices : JOINTS, float4 weights : WEIGHTS)
{
	PSInput result;

	float4x4 finalMatrix = mul(projMat, mvMat);
	
	float4x4 boneTransform = mul(joints[jointIndices.x], weights.x)
		+ mul(joints[jointIndices.y], weights.y)
		+ mul(joints[jointIndices.z], weights.z)
		+ mul(joints[jointIndices.w], weights.w);
	
	float4 skinnedPosition = mul(boneTransform, float4(position, 1.0));
	result.position = mul(finalMatrix, skinnedPosition);
	result.uv = uv;
	result.color = float4(color, 1.0);
	result.normal = float4(normal, 1.0);

	return result;
}

float4 PSMain(PSInput input) : SV_TARGET
{
	float4 outColor = input.color * g_texture.Sample(g_sampler, input.uv);
	if(outColor.a < 0.3)
		discard;
	return outColor;
}
